Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(351)

Unified Diff: components/sync/engine_impl/get_updates_processor.h

Issue 2258873003: [Sync] Move sessions/ to engine/cycle/ and rename things to match. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address comments. Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/sync/engine_impl/get_updates_processor.h
diff --git a/components/sync/engine_impl/get_updates_processor.h b/components/sync/engine_impl/get_updates_processor.h
index 9eb574c315edfaa2ffd4d68a01d676f5a2e44554..d49b062918162587701c6583710b7c2e3dc19a87 100644
--- a/components/sync/engine_impl/get_updates_processor.h
+++ b/components/sync/engine_impl/get_updates_processor.h
@@ -22,19 +22,16 @@ class GetUpdatesResponse;
namespace syncer {
-namespace sessions {
-class StatusController;
-class SyncSession;
-class SyncSessionContext;
class DebugInfoGetter;
-} // namespace sessions
+class GetUpdatesDelegate;
+class StatusController;
+class SyncCycle;
+class SyncCycleContext;
namespace syncable {
class Directory;
} // namespace syncable
-class GetUpdatesDelegate;
-
// This class manages the set of per-type syncer objects.
//
// It owns these types and hides the details of iterating over all of them.
@@ -53,12 +50,11 @@ class GetUpdatesProcessor {
// download succeeded but there are still some updates left to fetch on the
// server, or an appropriate error value in case of failure.
SyncerError DownloadUpdates(ModelTypeSet* request_types,
- sessions::SyncSession* session,
+ SyncCycle* cycle,
bool create_mobile_bookmarks_folder);
// Applies any downloaded and processed updates.
- void ApplyUpdates(ModelTypeSet gu_types,
- sessions::StatusController* status_controller);
+ void ApplyUpdates(ModelTypeSet gu_types, StatusController* status_controller);
private:
// Populates a GetUpdates request message with per-type information.
@@ -66,24 +62,24 @@ class GetUpdatesProcessor {
sync_pb::ClientToServerMessage* message);
// Sends the specified message to the server and stores the response in a
// member of the |session|'s StatusController.
SyncerError ExecuteDownloadUpdates(ModelTypeSet* request_types,
- sessions::SyncSession* session,
+ SyncCycle* cycle,
sync_pb::ClientToServerMessage* msg);
// Helper function for processing responses from the server. Defined here for
// testing.
SyncerError ProcessResponse(const sync_pb::GetUpdatesResponse& gu_response,
ModelTypeSet proto_request_types,
- sessions::StatusController* status);
+ StatusController* status);
// Processes a GetUpdates responses for each type.
syncer::SyncerError ProcessGetUpdatesResponse(
ModelTypeSet gu_types,
const sync_pb::GetUpdatesResponse& gu_response,
- sessions::StatusController* status_controller);
+ StatusController* status_controller);
- static void CopyClientDebugInfo(sessions::DebugInfoGetter* debug_info_getter,
+ static void CopyClientDebugInfo(DebugInfoGetter* debug_info_getter,
sync_pb::DebugInfo* debug_info);
FRIEND_TEST_ALL_PREFIXES(GetUpdatesProcessorTest, BookmarkNudge);
« no previous file with comments | « components/sync/engine_impl/get_updates_delegate.cc ('k') | components/sync/engine_impl/get_updates_processor.cc » ('j') | no next file with comments »
@@ -66,24 +62,24 @@ class GetUpdatesProcessor {
sync_pb::ClientToServerMessage* message);
// Sends the specified message to the server and stores the response in a
- // member of the |session|'s StatusController.
+ // member of the |cycle|'s StatusController.
SyncerError ExecuteDownloadUpdates(ModelTypeSet* request_types,

Powered by Google App Engine
This is Rietveld 408576698